@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "An unknown error has occurred",
     "File could not be uploaded" : "File could not be uploaded",
     "Uploading …" : "Uploading …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Uploading … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Uploading that item is not supported",
     "Target folder does not exist any more" : "Target folder does not exist any more",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Move",
     "Copy" : "Copy",
     "Choose target folder" : "Choose target folder",
+    "Set reminder" : "Set reminder",
     "Edit locally" : "Edit locally",
     "Open" : "Open",
     "Delete file" : "Delete file",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
     "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
     "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
+    "New" : "New",
     "New file/folder menu" : "New file/folder menu",
     "Select file range" : "Select file range",
     "{used}%" : "{used}%",
@@ -107,8 +111,6 @@ OC.L10N.register(
     "Create new folder" : "Create new folder",
     "Upload file" : "Upload file",
     "Recent" : "Recent",
-    "This file has the tag {tag}" : "This file has the tag {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "This file has the tags {firstTags} and {lastTag}",
     "Not favorited" : "Not favourited",
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
@@ -154,7 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favourites</strong>",
     "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "A favourite file or folder has been <strong>changed</strong>",
-    "All files" : "All files",
     "Upload (max. %s)" : "Upload (max. %s)",
     "Accept" : "Accept",
     "Reject" : "Reject",
@@ -168,37 +169,46 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
     "in %s" : "in %s",
     "File Management" : "File Management",
+    "Current directory path" : "Current directory path",
     "Reload current directory" : "Reload current directory",
     "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
-    "Select the row for {displayName}" : "Select the row for {displayName}",
-    "Rename file" : "Rename file",
-    "File name" : "File name",
-    "A long time ago" : "A long time ago",
-    "Download file {name}" : "Download file {name}",
+    "Drag and drop files here to upload" : "Drag and drop files here to upload",
+    "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
+    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
+    "Upload successful" : "Upload successful",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
+    "Toggle selection for file \"{displayName}\"" : "Toggle selection for file \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Toggle selection for folder \"{displayName}\"",
+    "Rename file" : "Rename file",
+    "File name" : "File name",
+    "Folder name" : "Folder name",
+    "This node is unavailable" : "This node is unavailable",
+    "Download file {name}" : "Download file {name}",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" is not an allowed filetype.",
     "{newName} already exists." : "{newName} already exists.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" is not allowed inside a file name.",
     "Name cannot be empty" : "Name cannot be empty",
     "Another entry with the same name already exists" : "Another entry with the same name already exists",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
-    "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
     "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
+    "Could not copy {file}. {message}" : "Could not copy {file}. {message}",
+    "Could not move {file}. {message}" : "Could not move {file}. {message}",
     "Total rows summary" : "Total rows summary",
-    "Select all" : "Select all",
-    "Unselect all" : "Unselect all",
+    "Toggle selection for all files and folders" : "Toggle selection for all files and folders",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" failed on some elements ",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
-    "ascending" : "ascending",
-    "descending" : "descending",
-    "Sort list by {column} ({direction})" : "Sort list by {column} ({direction})",
     "List of files and folders." : "List of files and folders.",
+    "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
+    "File not found" : "File not found",
     "Storage informations" : "Storage informations",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
     "{relative}% used" : "{relative}% used",
     "Could not refresh storage stats" : "Could not refresh storage stats",
+    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
     "Transfer ownership of a file or folder" : "Transfer ownership of a file or folder",
     "Choose file or folder to transfer" : "Choose file or folder to transfer",
     "Change" : "Change",
@@ -211,20 +221,33 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Ownership transfer request sent",
     "Cannot transfer ownership of a file or folder you do not own" : "Cannot transfer ownership of a file or folder you do not own",
     "Select file or folder to link to" : "Select file or folder to link to",
+    "Choose file" : "Choose file",
+    "Choose {file}" : "Choose {file}",
+    "Add" : "Add",
     "Loading current folder" : "Loading current folder",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "Go to the previous folder" : "Go to the previous folder",
     "Go back" : "Go back",
+    "Share" : "Share",
+    "Shared by link" : "Shared by link",
+    "Shared" : "Shared",
+    "Switch to list view" : "Switch to list view",
+    "Switch to grid view" : "Switch to grid view",
+    "Error during upload: {message}" : "Error during upload: {message}",
+    "Error during upload, status code {status}" : "Error during upload, status code {status}",
+    "Unknown error during upload" : "Unknown error during upload",
     "Open the files app settings" : "Open the files app settings",
     "Files settings" : "Files settings",
     "File cannot be accessed" : "File cannot be accessed",
-    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
     "Sort favorites first" : "Sort favourites first",
+    "Sort folders before files" : "Sort folders before files",
     "Show hidden files" : "Show hidden files",
     "Crop image previews" : "Crop image previews",
+    "Enable the grid view" : "Enable the grid view",
     "Additional settings" : "Additional settings",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "Copy to clipboard",
     "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
@@ -239,44 +262,71 @@ OC.L10N.register(
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
     "Delete permanently" : "Delete permanently",
+    "Destination is not a folder" : "Destination is not a folder",
+    "This file/folder is already in that directory" : "This file/folder is already in that directory",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
+    "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
+    "The files is locked" : "The files is locked",
+    "The file does not exist anymore" : "The file does not exist anymore",
+    "Choose destination" : "Choose destination",
+    "Copy to {target}" : "Copy to {target}",
+    "Move to {target}" : "Move to {target}",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
+    "Move or copy operation failed" : "Move or copy operation failed",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
     "Open details" : "Open details",
-    "Set up templates folder" : "Set up templates folder",
-    "Templates" : "Templates",
     "Create new templates folder" : "Create new templates folder",
+    "Templates" : "Templates",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
+    "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
+    "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
+    "Uploading \"{filename}\" failed" : "Uploading \"{filename}\" failed",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
     "List of favorites files and folders." : "List of favourites files and folders.",
     "No favorites yet" : "No favourites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
+    "All files" : "All files",
+    "List of your files and folders." : "List of your files and folders.",
     "List of recently modified files and folders." : "List of recently modified files and folders.",
     "No recently modified files" : "No recently modified files",
     "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
-    "Toggle %1$s sublist" : "Toggle %1$s sublist",
-    "Toggle grid view" : "Toggle grid view",
     "No entries found in this folder" : "No entries found in this folder",
+    "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt",
-    "Storage invalid" : "Storage invalid",
     "You can only favorite a single file or folder at a time" : "You can only favourite a single file or folder at a time",
-    "Unlimited" : "Unlimited",
     "Search users" : "Search users",
+    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
     "Cancel" : "Cancel",
-    "%s used" : "%s used",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s of %2$s used",
+    "Set up templates folder" : "Set up templates folder",
+    "Toggle %1$s sublist" : "Toggle %1$s sublist",
+    "Toggle grid view" : "Toggle grid view",
     "Deleted files" : "Deleted files",
     "Shares" : "Shares",
     "Shared with others" : "Shared with others",
     "Shared with you" : "Shared with you",
-    "Shared by link" : "Shared by link",
     "Deleted shares" : "Deleted shares",
     "Pending shares" : "Pending shares",
+    "This file has the tag {tag}" : "This file has the tag {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "This file has the tags {firstTags} and {lastTag}",
+    "Select the row for {displayName}" : "Select the row for {displayName}",
     "Open folder {name}" : "Open folder {name}",
+    "Unselect all" : "Unselect all",
+    "ascending" : "ascending",
+    "descending" : "descending",
+    "Sort list by {column} ({direction})" : "Sort list by {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list.",
     "Search for an account" : "Search for an account",
+    "Choose" : "Choose",
     "No files or folders have been deleted yet" : "No files or folders have been deleted yet"
 },
 "nplurals=2; plural=(n != 1);");
