@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Произошла неизвестная ошибка",
     "File could not be uploaded" : "Файл не может быть загружен",
     "Uploading …" : "Передача…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Загрузка … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
     "Target folder does not exist any more" : "Каталог больше не существует",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Переместить",
     "Copy" : "Копировать",
     "Choose target folder" : "Выбор папки назначения",
+    "Set reminder" : "Установить напоминание",
     "Edit locally" : "Редактировать локально",
     "Open" : "Открыть",
     "Delete file" : "Удалить файл",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
     "You do not have permission to upload or create files here" : "У вас нет разрешения на загрузку или создание файлов здесь",
     "_Uploading %n file_::_Uploading %n files_" : ["Передача %n файла","Передача %n файлов","Передача %n файлов","Передача %n файлов"],
+    "New" : "Новый",
     "New file/folder menu" : "Меню создания файла или папки",
     "Select file range" : "Выбор диапазона файлов",
     "{used}%" : "{used}%",
@@ -107,8 +111,6 @@ OC.L10N.register(
     "Create new folder" : "Создать папку",
     "Upload file" : "Загрузить файл",
     "Recent" : "Недавно изменённые",
-    "This file has the tag {tag}" : "У этого файла есть тэг: {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "У этого файла есть тэги: {firstTags} и {lastTag}",
     "Not favorited" : "Не избранное",
     "Remove from favorites" : "Удалить из избранных",
     "Add to favorites" : "Добавить в избранное",
@@ -154,7 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
     "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
     "A favorite file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или папка отмеченные как избранное",
-    "All files" : "Все файлы",
     "Upload (max. %s)" : "Загрузка (максимум %s)",
     "Accept" : "Принять",
     "Reject" : "Отклонить",
@@ -168,36 +169,43 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
     "in %s" : "в %s",
     "File Management" : "Управление файлами",
+    "Current directory path" : "Текущий путь к каталогу",
     "Reload current directory" : "Обновить текущий каталог",
     "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
-    "Select the row for {displayName}" : "Выбрать строку для {displayName}",
+    "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
+    "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
+    "You don’t have permission to upload or create files here" : "У вас нет прав на создание или загрузку файлов в эту папку.",
+    "Upload successful" : "Загружено успешно",
+    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
+    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
     "Rename file" : "Переименовать файл",
     "File name" : "Имя файла",
-    "A long time ago" : "Очень давно",
+    "Folder name" : "Имя папки",
+    "This node is unavailable" : "Этот узел недоступен",
     "Download file {name}" : "Скачать файл {name}",
-    "\"{displayName}\" action executed successfully" : "Действие \"{displayName}\" выполнено успешно",
-    "\"{displayName}\" action failed" : "Действие \"{displayName}\" завершилось неудачно",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" не является допустимым типом файла.",
-    "{newName} already exists." : "{newName} уже существует.",
+    "\"{name}\" is not an allowed filetype." : "«{name}» не является допустимым типом файла.",
+    "{newName} already exists." : "«{newName}» уже существует.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" не допускается внутри имени файла.",
     "Name cannot be empty" : "Имя не может быть пустым",
     "Another entry with the same name already exists" : "Другая запись с таким названием уже существует",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано \"{oldName}\" в \"{newName}\"",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
-    "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
-    "Could not rename \"{oldName}\"" : "Не удалось переименовать \"{oldName}\"",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
+    "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
+    "Could not copy {file}. {message}" : "Ошибка копирования «{file}». {message}",
+    "Could not move {file}. {message}" : "Ошибка перемещения «{file}». {message}",
     "Total rows summary" : "Количество строк в общем",
-    "Select all" : "Выбрать всё",
-    "Unselect all" : "Отменить выделение для всех",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" неудачно для некоторых элементов",
+    "\"{displayName}\" failed on some elements " : "«{displayName}» неудачно для некоторых элементов",
     "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
-    "ascending" : "восходящий",
-    "descending" : "нисходящий",
-    "Sort list by {column} ({direction})" : "Сортировать список по {column} ({direction})",
     "List of files and folders." : "Список файлов и каталогов.",
+    "Column headers with buttons are sortable." : "Заголовки столбцов с кнопками можно сортировать.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
+    "File not found" : "Файл не найден",
     "Storage informations" : "Сведения о хранилище",
     "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
     "{relative}% used" : "Использовано {relative}%",
     "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
+    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы.",
     "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
     "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
     "Change" : "Изменить",
@@ -210,20 +218,31 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
     "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
     "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
+    "Choose file" : "Выберите файл",
+    "Choose {file}" : "Выберан {file}",
+    "Add" : "Добавить",
     "Loading current folder" : "Загрузка текущей папки",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "Go to the previous folder" : "Перейти к предыдущей папке",
     "Go back" : "Назад",
+    "Share" : "Поделиться",
+    "Shared by link" : "Доступные по ссылке",
+    "Shared" : "Опубликованное",
+    "Switch to list view" : "Переключение в режим просмотра списка",
+    "Switch to grid view" : "Переключиться на режим просмотра сеткой",
+    "Error during upload: {message}" : "Ошибка при загрузке: {message}",
+    "Unknown error during upload" : "Неизвестная ошибка при загрузке",
     "Open the files app settings" : "Открыть параметры приложения «Файлы»",
     "Files settings" : "Настройки файлов",
     "File cannot be accessed" : "Не удалось получить доступ к файлу",
-    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
     "Sort favorites first" : "Сначала избранное",
     "Show hidden files" : "Показывать скрытые файлы",
     "Crop image previews" : "Обрезать пред. просмотр",
+    "Enable the grid view" : "Включить режим просмотра сеткой",
     "Additional settings" : "Дополнительные параметры",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "Ссылка WebDAV",
     "Copy to clipboard" : "Копировать в буфер",
     "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы используете двухфакторную аутентификацию, то нажмите здесь чтобы создать пароль приложения.",
@@ -238,40 +257,68 @@ OC.L10N.register(
     "Blank" : "Пустой",
     "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
     "Delete permanently" : "Удалить навсегда",
+    "Destination is not a folder" : "Указанное назначение не является папкой",
+    "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
+    "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
+    "The files is locked" : "Файлы заблокированы",
+    "The file does not exist anymore" : "Файл больше не существует",
+    "Choose destination" : "Выберите место назначения",
+    "Copy to {target}" : "Скопировать в «{target}»",
+    "Move to {target}" : "Переместить в «{target}»",
+    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
     "Open folder {displayName}" : "Открыть каталог {displayName}",
+    "Open in Files" : "Открыть в Файлах",
     "Open details" : "Открыть подробности",
-    "Set up templates folder" : "Указать папку шаблонов",
-    "Templates" : "Шаблоны",
     "Create new templates folder" : "Создать новую папку шаблонов",
+    "Templates" : "Шаблоны",
     "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
+    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
+    "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
+    "Uploading \"{filename}\" failed" : "Загрузка \"{filename}\" не удалась",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{count} папка","{count} папки","{count} папок","{count} папки"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{count} файл","{count} файла","{count} файлов","{count} файла"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {count} папка","один файл и {count} папки","один файл и {count} папок","один файл и {count} папки"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
+    "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
     "List of favorites files and folders." : "Список избранных файлов и каталогов.",
     "No favorites yet" : "В избранное ещё ничего не добавлено ",
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
-    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
-    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
+    "All files" : "Все файлы",
+    "List of your files and folders." : "Список ваших файлов и каталогов.",
+    "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
+    "No recently modified files" : "Нет недавно измененных файлов",
+    "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
     "No entries found in this folder" : "В этом каталоге ничего не найдено",
+    "Select all" : "Выбрать всё",
     "Upload too large" : "Файл слишком велик",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
     "Text file" : "Текстовый файл",
     "New text file.txt" : "Новый текстовый файл.txt",
-    "Storage invalid" : "Хранилище неисправно",
     "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
-    "Unlimited" : "Неограничено",
     "Search users" : "Поиск пользователей",
+    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
     "Cancel" : "Отменить",
-    "%s used" : "%s использовано",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
+    "Set up templates folder" : "Указать папку шаблонов",
+    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
+    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
     "Deleted files" : "Корзина",
     "Shares" : "Общие ресурсы",
     "Shared with others" : "Доступные для других",
     "Shared with you" : "Доступные для вас",
-    "Shared by link" : "Доступные по ссылке",
     "Deleted shares" : "Удалённые общие ресурсы",
     "Pending shares" : "Ожидающие общие ресурсы",
+    "This file has the tag {tag}" : "Файлу назначана метка «{tag}»",
+    "This file has the tags {firstTags} and {lastTag}" : "Файлу назначены метки «{firstTags}» и «{lastTag}»",
+    "Select the row for {displayName}" : "Выбрать строку для {displayName}",
     "Open folder {name}" : "Открыть папку {name}",
+    "Unselect all" : "Отменить выделение для всех",
+    "ascending" : "восходящий",
+    "descending" : "нисходящий",
+    "Sort list by {column} ({direction})" : "Сортировать список по {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
     "Search for an account" : "Поиск по учетной записи",
+    "Choose" : "Выберите",
     "No files or folders have been deleted yet" : "Файлы или папки еще не удалены"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
