@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "التطبيق %1$s غير موجود أو ليس له إصدار متطابق مع هذا الخادوم. رجاءً، راجع دليل التطبيقات apps directory.",
     "Sample configuration detected" : "تمّ العثور على عيّنة إعدادات sample configuration.",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تمّ اكتشاف أن عيّنة الإعدادات قد تمّ نسخها. يُمكن لهذا أن يُعطّل عملية التنصيب و هو أمر غير مدعوم. نرجو الاطلاع على التعليمات الواردة في وثائق النظام قبل إحداث أي تعديلات على ملف config.php",
-    "404" : "404",
     "The page could not be found on the server." : "تعذّر العثور على الصفحة في الخادوم",
     "%s email verification" : "%s التحقّق من الإيميل",
     "Email verification" : "التحقّق من الإيميل",
@@ -156,6 +155,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
     "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
     "The requested share does not exist anymore" : "المشاركة المطلوبة لم تعد موجودةً",
+    "The requested share comes from a disabled user" : "المستخدم الذي طلب المشاركة تمّ تجميد حسابه بعد طلبه للمشاركة",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "لم يتم إنشاء المستخدم بسبب وصول عدد المستخدمين إلى الحد الأقصى المسموح به. رجاءً، راجع إشعاراتك للمزيد من المعلومات.",
     "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
     "Sunday" : "الأحد",
@@ -244,8 +244,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "يرجى مطالبة مسؤول الخادم بإعادة تشغيل خادم الويب.",
     "The required %s config variable is not configured in the config.php file." : "مُتغيّر التهيئة %s المطلوب لم تتم تهيئته في الملف config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مشرف نظامك مراجعة تهيئة نكست كلاود Nextcloud configuration.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 مطلوبة.",
-    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك.",
     "Your data directory is readable by other users." : "دليل بياناتك data directory يُمكن قراءته من مستخدمين آخرين.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد.",
     "Your data directory must be an absolute path." : "مسار دليل بياناتك data directory يجب أن يكون مساراً مُطلقاً absolute path.",
@@ -272,10 +270,11 @@ OC.L10N.register(
     "Extract topics" : "إستخلاص الموضوعات",
     "Extracts topics from a text and outputs them separated by commas." : "يستخلص المواضيع من النص و إخراجها مفصولة بفواصل.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "ملفات التطبيق %1$s لم يتم استبدالها مؤخّراً. تأكد من تطابق إصدارها مع الخادوم.",
+    "404" : "404",
     "Full name" : "الاسم الكامل",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "بسبب الوصول إلى الحدّ الأقصى من عدد المستخدمين، لم يتم إنشا المستخدم. رجاءً، راجع إشعاراتك لمزيد المعلومات.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "مسموح باستخدام الأحرف التالية فقط في اسم المستخدم: \"a-z\" و \"A-Z\" و \"0-9\" و \"_. @ - '\"",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "نحتاج النسخة 2.7.0 من libxml2 على الأقل. النسخة المتوافرة حالياً هي %s",
-    "To fix this issue update your libxml2 version and restart your web server." : "لإصلاح هذه المشكلة، قم بتحديث إصدار libxml2 الخاص بك وأعد تشغيل خادم الويب."
+    "To fix this issue update your libxml2 version and restart your web server." : "لإصلاح هذه المشكلة، قم بتحديث إصدار libxml2 الخاص بك وأعد تشغيل خادم الويب.",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 مطلوبة.",
+    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
